summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--README6
-rwxr-xr-xbin/reproducible_build_service.sh15
2 files changed, 13 insertions, 8 deletions
diff --git a/README b/README
index 3fe2455f..fc9f7bf3 100644
--- a/README
+++ b/README
@@ -143,10 +143,10 @@ Installation tests inside chroot environments.
** for 'amd64' we are using four virtual machines, profitbricks-build(1+5+11+15)-amd64, which have 15 or 16 cores and 48gb ram each. These nodes are sponsored by link:https://jenkins.debian.net/userContent/thanks.html[Profitbricks].
** for 'i386' we are also using four virtual machines, profitbricks-build(2+6+12+16)-i386, which have 10 or 9 cores and 36gb ram each. pb2+12 run emulated AMD Opteron CPUs and pb6+16 Intel Xeon CPUs. These nodes are also sponsored by link:https://jenkins.debian.net/userContent/thanks.html[Profitbricks].
** for 'arm64' we are using eight "moonshot" sleds, codethink-sled9-15-arm64, which have 8 cores and 64gb ram each. These nodes are sponsored by link:https://jenkins.debian.net/userContent/thanks.html[Codethink].
-** To test 'armhf' we are using 27 small boards donated by vagrant@d.o:
-*** four quad-cores (cbxi4a, cbxi4b, ff4a, jtx1a, jtx1b) with 4gb ram,
+** To test 'armhf' we are using 29 small boards hosted by vagrant@d.o:
+*** five quad-cores (cbxi4a, cbxi4b, ff4a, jtx1a, jtx1b, jtx1c) with 4gb ram,
*** three octo-cores (odxu4, odxu4b and odxu4c) with 2gb ram,
-*** eleven quad-cores (wbq0, cbxi4pro0, ff2a, ff2b, odu3a, opi2a, opi2b, opi2c, jtk1b, p64b and p64c) with 2gb ram,
+*** twelve quad-cores (wbq0, cbxi4pro0, ff2a, ff2b, odu3a, opi2a, opi2b, opi2c, jtk1a, jtk1b, p64b and p64c) with 2gb ram,
*** two dual-core (bbx15 and cb3a) with 2gb ram and,
*** two quad-cores (rpi2b and rpi2c) with 1gb ram and
*** three dual-cores (bpi0, hb0 and wbd0) with 1gb ram, each.
diff --git a/bin/reproducible_build_service.sh b/bin/reproducible_build_service.sh
index abcda366..84184425 100755
--- a/bin/reproducible_build_service.sh
+++ b/bin/reproducible_build_service.sh
@@ -116,7 +116,7 @@ choose_nodes() {
arm64_31) NODE1=codethink-sled14-arm64 NODE2=codethink-sled11-arm64 ;;
arm64_32) NODE1=codethink-sled13-arm64 NODE2=codethink-sled14-arm64 ;;
# to choose new armhf jobs:
# for i in cb3a hb0 rpi2b rpi2c wbd0 bpi0 bbx15 cbxi4pro0 ff2a ff2b ff64a jtk1a jtk1b odxu4 odxu4b odxu4c odu3a opi2a opi2b opi2c p64b p64c wbq0 cbxi4a cbxi4b ff4a jtx1a jtx1b ; do echo "$i: " ; grep NODE1 bin/reproducible_build_service.sh|grep armhf|grep $i-armhf ; done
# 6 jobs for quad-cores with 4 gb ram
# 4 jobs for octo-cores with 2 gb ram
# 4 jobs for hexa-cores with 2 gb ram
@@ -130,7 +130,7 @@ choose_nodes() {
armhf_1) NODE1=bbx15-armhf-rb NODE2=jtx1a-armhf-rb ;;
armhf_2) NODE1=bbx15-armhf-rb NODE2=ff4a-armhf-rb ;;
armhf_3) NODE1=cb3a-armhf-rb NODE2=jtx1a-armhf-rb ;;
- armhf_4) NODE1=cb3a-armhf-rb NODE2=wbq0-armhf-rb ;;
+ armhf_4) NODE1=cb3a-armhf-rb NODE2=jtx1c-armhf-rb ;;
armhf_5) NODE1=hb0-armhf-rb NODE2=p64c-armhf-rb ;;
armhf_6) NODE1=rpi2b-armhf-rb NODE2=ff4a-armhf-rb ;;
armhf_7) NODE1=rpi2c-armhf-rb NODE2=cbxi4b-armhf-rb ;;
@@ -150,7 +150,7 @@ choose_nodes() {
armhf_21) NODE1=odxu4-armhf-rb NODE2=opi2a-armhf-rb ;;
armhf_22) NODE1=odxu4b-armhf-rb NODE2=odu3a-armhf-rb ;;
armhf_23) NODE1=odxu4b-armhf-rb NODE2=jtk1b-armhf-rb ;;
- armhf_24) NODE1=odxu4c-armhf-rb NODE2=odu3a-armhf-rb ;;
+ armhf_24) NODE1=odxu4c-armhf-rb NODE2=jtx1c-armhf-rb ;;
armhf_25) NODE1=odxu4c-armhf-rb NODE2=jtk1b-armhf-rb ;;
armhf_26) NODE1=odu3a-armhf-rb NODE2=odxu4-armhf-rb ;;
armhf_27) NODE1=odu3a-armhf-rb NODE2=jtx1b-armhf-rb ;;
@@ -172,13 +172,18 @@ choose_nodes() {
armhf_43) NODE1=cbxi4b-armhf-rb NODE2=bbx15-armhf-rb ;;
armhf_44) NODE1=cbxi4b-armhf-rb NODE2=cb3a-armhf-rb ;;
armhf_45) NODE1=cbxi4b-armhf-rb NODE2=hb0-armhf-rb ;;
- armhf_46) NODE1=ff4a-armhf-rb NODE2=bpi0-armhf-rb ;;
+ armhf_46) NODE1=ff4a-armhf-rb NODE2=jtk1a-armhf-rb ;;
armhf_47) NODE1=ff4a-armhf-rb NODE2=wbd0-armhf-rb ;;
- armhf_48) NODE1=ff4a-armhf-rb NODE2=cbxi4a-armhf-rb ;;
+ armhf_48) NODE1=ff4a-armhf-rb NODE2=jtx1c-armhf-rb ;;
armhf_49) NODE1=jtx1a-armhf-rb NODE2=cbxi4a-armhf-rb ;;
armhf_50) NODE1=jtx1a-armhf-rb NODE2=rpi2b-armhf-rb ;;
armhf_51) NODE1=jtx1a-armhf-rb NODE2=odxu4-armhf-rb ;;
armhf_52) NODE1=jtx1b-armhf-rb NODE2=bbx15-armhf-rb ;;
+ armhf_53) NODE1=jtx1c-armhf-rb NODE2=jtk1a-armhf-rb ;;
+ armhf_54) NODE1=jtx1c-armhf-rb NODE2=cbxi4a-armhf-rb ;;
+ armhf_55) NODE1=jtx1c-armhf-rb NODE2=odu3a-armhf-rb ;;
+ armhf_56) NODE1=jtk1a-armhf-rb NODE2=wbq0-armhf-rb ;;
+ armhf_57) NODE1=jtk1a-armhf-rb NODE2=bpi0-armhf-rb ;;
*) NODE1=undefined
;;
esac
@@ -116,7 +116,7 @@ choose_nodes() {
arm64_32) NODE1=codethink-sled13-arm64 NODE2=codethink-sled14-arm64 ;;
# to choose new armhf jobs:
- # for i in cb3a hb0 rpi2b rpi2c wbd0 bpi0 bbx15 cbxi4pro0 ff2a ff2b ff64a jtk1a jtk1b odxu4 odxu4b odxu4c odu3a opi2a opi2b opi2c p64b p64c wbq0 cbxi4a cbxi4b ff4a jtx1a jtx1b ; do echo "$i: " ; grep NODE1 bin/reproducible_build_service.sh|grep armhf|grep $i-armhf ; done
+ # for i in hb0 rpi2b rpi2c wbd0 bpi0 cb3a bbx15 cbxi4pro0 ff2a ff2b jtk1a jtk1b odxu4 odxu4b odxu4c odu3a opi2a opi2b opi2c p64b p64c wbq0 cbxi4a cbxi4b ff4a jtx1a jtx1b jtx1c; do echo "$i: " ; grep NODE1 bin/reproducible_build_service.sh|grep armhf|grep $i-armhf ; done
# 6 jobs for quad-cores with 4 gb ram
# 4 jobs for octo-cores with 2 gb ram